@@ -23,8 +23,8 @@ SOFTWARE.
 """
 from cereja.utils import get_version_pep440_compliant
 from . import settings
-from .devices import Capture, Mouse, VideoMagnify, VideoWriter
-from .media import Image
+from .devices import Mouse
+from .media import Image, VideoWriter, Video
 
-VERSION = "1.1.1.final.0"
+VERSION = "2.0.0.final.0"
 __version__ = get_version_pep440_compliant(VERSION)
